@@ -1,6 +1,4 @@
 import os
-import sys
-import subprocess
 
 VERSION = '3.47'
 SRC_URL = (
